package com.facishare.connector.aop;
import com.facishare.connector.utils.ErrorDataWatchUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.time.StopWatch;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.stereotype.Component;

/**
 * @author chenxf
 * Created on 2020/5/27
 * 简单的aop日志监控
 */
@Aspect
@Slf4j
@Component
public class LogAop {

    @Around("execution(* com.facishare.connector.controller.*.*(..))"
      + "||execution(* com.facishare.connector.*.service.impl.*.*(..))")
    public Object interceptor(ProceedingJoinPoint point) throws Throwable {
        Object result = null;
        // 获取类的完整路径和方法名称
        String fullClassName = point.getTarget().getClass().getName();
        String methodName = point.getSignature().getName();
        //计时器
        StopWatch stopWatch = new StopWatch();
        stopWatch.start();
        //处理结果直接返回
        try {
            result = point.proceed();
            stopWatch.stop();
            log.info(" AOP trace fullClassName:{} ,totalTime:{}ms,methodName:{} arg{}, result:{}",  fullClassName, stopWatch.getTime(), methodName,point.getArgs(),result);
        }catch (Exception e){
            ErrorDataWatchUtil.record();
            if (fullClassName.contains("controller")){
                log.error(" classname:{}, methedName:{}, args:{}, result:{},exception",
                  fullClassName, methodName, point.getArgs(),result, e);
            }else {
                log.error(" classname:{}, methedName:{}, args:{}, result:{},exception,{}",
                  fullClassName, methodName, point.getArgs(),result,e.getMessage());
            }
            stopWatch.stop();
            throw e;
        }
        return result;
    }
}
