package com.facishare.connector.auths;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpMethod;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.config.http.SessionCreationPolicy;
import org.springframework.security.web.authentication.UsernamePasswordAuthenticationFilter;

@Configuration
@EnableWebSecurity(debug = false)
public class SecurityConfig extends WebSecurityConfigurerAdapter {

    @Autowired
    @Qualifier("authenticationSuccessHandler")
    private AuthenticationSuccessHandler successHandler;

    @Autowired
    @Qualifier("authenticationFailHandler")
    private AuthenticationFailHandler failHandler;

    @Autowired
    @Qualifier("authenticationEntryPointImpl")
    private AuthenticationEntryPointImpl entryPoint;

    @Override
    protected void configure(HttpSecurity http) throws Exception {
        http.sessionManagement().sessionCreationPolicy(SessionCreationPolicy.IF_REQUIRED)
                .and().csrf().disable()
                .authorizeRequests()
                .antMatchers(HttpMethod.GET, "/test").permitAll()
                .antMatchers("/reLogin", "/login.html", "/test").permitAll()
                .anyRequest().authenticated()
                .antMatchers("/middleware/sync/adapt/**").hasAuthority("admin")
                .and().formLogin().loginProcessingUrl("/login").loginPage("/login.html")
                .successHandler(successHandler)
                .failureHandler(failHandler)
                .and().sessionManagement().invalidSessionUrl("/reLogin")
                .and().exceptionHandling().authenticationEntryPoint(entryPoint)//增加这行会掩盖默认的登陆页面
                .and().addFilterBefore(new TokenFilter(), UsernamePasswordAuthenticationFilter.class);
    }


//    @Override
//    protected void configure(AuthenticationManagerBuilder auth) throws Exception {
//        final String name = environment.getProperty("spring.security.user.name");
//        final String password = environment.getProperty("spring.security.user.password");
//
//        auth.inMemoryAuthentication()
//                // 定义加密方式，不然启动不了
//                .passwordEncoder(passwordEncoder())
//                // 设置用户名
//                .withUser(name)
//                // 设置密码（密文密码）
//                .password(passwordEncoder().encode(password))
//                // 设置角色，不设置启动不了
//                .roles("admin");
//    }
//
//    private PasswordEncoder passwordEncoder() {
//        return new BCryptPasswordEncoder();
//    }
}
