package com.facishare.connector.auths;

import org.apache.commons.lang3.StringUtils;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.web.filter.OncePerRequestFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.util.Collections;
import java.util.Properties;

/**
 * @author chenxiaobin
 * @date 2023/8/8 16:15:31
 */
public class TokenFilter extends OncePerRequestFilter {

    private static String TOKEN;

    private static PasswordEncoder passwordEncoder = new BCryptPasswordEncoder();

    static {
        Properties properties = new Properties();

        try (InputStream inputStream = TokenFilter.class.getClassLoader().getResourceAsStream("application.properties")) {
            properties.load(inputStream);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }

        String propertyValue = properties.getProperty("spring.security.user.token");
        TOKEN = passwordEncoder.encode(propertyValue);
    }

    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain) throws ServletException, IOException {
        if (!request.getRequestURI().contains("/middleware/sync/adapt")) {
            filterChain.doFilter(request, response);
            return;
        }

        // 从请求的header中获取token
        String token = request.getHeader("X-fs-erpdss-token");
        if (StringUtils.isEmpty(token)) {
            response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
            return;
        }

        // 根据token确定用户的角色
        String role = getUserRoleByToken(token);
        if (StringUtils.isEmpty(role)) {
            response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
            return;
        }

        // 将角色信息存入SecurityContextHolder中
        final UsernamePasswordAuthenticationToken authentication = new UsernamePasswordAuthenticationToken(null, null, Collections.singleton(new SimpleGrantedAuthority(role)));
        SecurityContextHolder.getContext().setAuthentication(authentication);

        // 继续处理请求
        filterChain.doFilter(request, response);
    }

    private String getUserRoleByToken(String token) {
        // 根据token确定用户的角色逻辑
        if (passwordEncoder.matches(token, TOKEN)) {
            return "admin";
        }
        return null;
    }
}
