package com.facishare.connector.controller;


import com.facishare.connector.constant.ResultEnum;
import com.facishare.connector.model.arg.InvalidRequestArg;
import com.facishare.connector.model.arg.SyncData;
import com.facishare.connector.model.result.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import java.text.SimpleDateFormat;
import java.util.*;

@Slf4j
@Controller
@RequestMapping("/middleware/sync/adapt")
@PreAuthorize("hasAuthority('admin')")
public class RouterAdaptController {

    private static String getHms(){
        SimpleDateFormat format = new SimpleDateFormat("ddHHmmss");
        return format.format(new Date());
    }

    private void setThreadName(String objectApiName){
        Thread.currentThread().setName("thread_run_"+"_"+objectApiName+"_"+ getHms());
    }

    @RequestMapping(value = "/create", method = RequestMethod.POST, produces = {"application/json; charset=UTF-8"})
    @ResponseBody
    public Result insertData(@RequestBody SyncData syncData) {
        Result result = new Result();
        try {
            String objAPIName = syncData.getObjAPIName();
            setThreadName(objAPIName);
            Map<String, Object> objectMap = new HashMap<>();  //insertData(syncData);
            result.setData(objectMap);
        } catch (Exception e) {
            result.setErrorCode(ResultEnum.SYSTEM_ERROR.getErrorCode());
            result.setErrorMessage(e.getMessage());
            log.error("新增数据失败：", e);
        }
        return result;
    }

    @RequestMapping(value = "/update", method = RequestMethod.POST, produces = {"application/json; charset=UTF-8"})
    @ResponseBody
    public Result updateData(@RequestBody SyncData syncData) {
        Result result = new Result();
        try {
            String objAPIName = syncData.getObjAPIName();
            setThreadName(objAPIName);
            Map<String, Object> objectMap =new HashMap<>();
            result.setData(objectMap);
        } catch (Exception e) {
            result.setErrorCode(ResultEnum.SYSTEM_ERROR.getErrorCode());
            result.setErrorMessage(e.getMessage());
            log.error("更新数据失败：", e);
        }

        return result;
    }

    @RequestMapping(value = "/invalid", method = RequestMethod.POST, produces = {"application/json; charset=UTF-8"})
    @ResponseBody
    public Result invalidData(@RequestBody InvalidRequestArg requestArg) {
        Result result = new Result();
        try {
            String objAPIName = requestArg.getObjAPIName();
            setThreadName(objAPIName);
            Map<String, Object> objectMap = new HashMap<>();
            result.setData(objectMap);
        } catch (Exception e) {
            result.setErrorCode(ResultEnum.SYSTEM_ERROR.getErrorCode());
            result.setErrorMessage(e.getMessage());
            log.error("作废数据失败：", e);
        }
        return result;
    }

    @RequestMapping(value = "/invalidDetail", method = RequestMethod.POST, produces = {"application/json; charset=UTF-8"})
    @ResponseBody
    public Result invalidDetail(@RequestBody InvalidRequestArg requestArg) {
        Result result = new Result();
        try {
            String objAPIName = requestArg.getObjAPIName();
            setThreadName(objAPIName);
            Map<String, Object> objectMap = new HashMap<>();
            result.setData(objectMap);
        } catch (Exception e) {
            result.setErrorCode(ResultEnum.SYSTEM_ERROR.getErrorCode());
            result.setErrorMessage(e.getMessage());
            log.error("更新数据失败：", e);
        }
        return result;
    }

    @RequestMapping("/queryMasterBatch")
    @ResponseBody
    public Result queryData(@RequestParam(name = "offset", defaultValue = "0") int offset,
                            @RequestParam(name = "limit", defaultValue = "100") int limit,
                            @RequestParam(name = "endTime", defaultValue = "0") Long endTime,
                            @RequestParam(name = "startTime", defaultValue = "0") Long startTime,
                            @RequestParam(name = "objAPIName") String objAPIName) {
        Result result = new Result();
        try {
            setThreadName(objAPIName);
            int page = (offset + limit) / limit;
            List<SyncData> datas = new ArrayList<>();
            Map dataListMap=new HashMap();
            dataListMap.put("dataList",datas);
            result.setData(dataListMap);
        } catch (Exception e) {
            result.setErrorCode(ResultEnum.SYSTEM_ERROR.getErrorCode());
            result.setErrorMessage(e.getMessage());
            log.error("查询列表失败：", e);
        }
        return result;
    }

    @RequestMapping("/queryMasterById")
    @ResponseBody
    public Result getData(@RequestParam("dataId") String id, @RequestParam(name = "objAPIName") String objAPIName) {
        Result result = new Result();
        try {
            setThreadName(objAPIName);
            SyncData data = new SyncData();
            result.setData(data);
        } catch (Exception e) {
            result.setErrorCode(ResultEnum.SYSTEM_ERROR.getErrorCode());
            result.setErrorMessage(e.getMessage());
            log.error("查询数据失败：", e);
        }
        return result;
    }

    //集成平台定期调用该接口检活
    @RequestMapping("/test")
    @ResponseBody
    public String test() {
        return "success";
    }
}
