package com.facishare.connector.model.result;

import com.facishare.connector.constant.ResultEnum;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;

/**
 * @author chenxf
 * Created on 2020/5/13
 */
@Data
@AllArgsConstructor
public class Result<T> implements Serializable {

    private static final long serialVersionUID = 564031526747534414L;

    /**
     * 返回码
     **/
    private Integer errorCode;

    /**
     * 返回描述
     **/
    private String errorMessage;

    /**
     * 实际数据
     **/
    private T data;

    public Result() {
        this.errorCode = ResultEnum.SUCCESS.getErrorCode();
        this.errorMessage = ResultEnum.SUCCESS.getErrorMessage();
    }

    public Result(ResultEnum resultCode) {
        this.errorCode = resultCode.getErrorCode();
        this.errorMessage = resultCode.getErrorMessage();
    }


    public Result(Integer errorCode, String errorMessage) {
        this.errorCode = errorCode;
        this.errorMessage = errorMessage;
    }

    public Result(T data) {
        this.errorCode = ResultEnum.SUCCESS.getErrorCode();
        this.errorMessage = "success";
        this.data = data;
    }

    public static <R> Result<R> newError(ResultEnum resultCode) {
        return new Result<>(resultCode);
    }

    public static <R> Result<R> newError(Integer errorCode, String errorMessage) {
        return new Result<>(errorCode, errorMessage);
    }

    public static <R> Result<R> newSuccess() {
        return new Result<>();
    }

    public static <R> Result<R> newSuccess(R data) {
        return new Result<>(data);
    }

    public boolean isSuccess() {
        if (ResultEnum.SUCCESS.getErrorCode().equals(errorCode)) {
            return true;
        }
        return false;
    }
}
