package com.facishare.connector.controller


import com.facishare.connector.auths.TokenFilter
import groovyx.net.http.ContentType
import groovyx.net.http.HTTPBuilder
import groovyx.net.http.Method
import org.springframework.boot.test.context.SpringBootTest
import spock.lang.Specification
import spock.lang.Unroll

/**
 * @author chenxiaobin
 * @date 2023/8/8 17:33:47
 */
@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.DEFINED_PORT)
class RouterAdaptControllerTest extends Specification {
    @Unroll
    def "测试权限-#id"() {
        when:
        def host = "http://localhost:8080/"
        def http = new HTTPBuilder(host + path)
        http.setHeaders(header)

        def statusCode
        String data
        def re = http.request(Method.GET, ContentType.TEXT) {
            response.success = { resp, json ->
                statusCode = resp.statusLine.statusCode
                data = new BufferedReader(json).readLine()
            }
            response.failure = { resp, json ->
                statusCode = resp.statusLine.statusCode
            }
        }


        then:
        statusCode == status
        data == null || data == result

        where:
        id             | path                         | header                            || status | result
        "不校验"       | "test"                       | [:]                               || 200    | "success"

        "检查身份"     | "adapt/test"                 | [:]                               || 406    | _

        "没有header"   | "middleware/sync/adapt/test" | [:]                               || 401    | _
        "没有token"    | "middleware/sync/adapt/test" | ["abc": "xxx"]                    || 401    | _

        "错误的header" | "middleware/sync/adapt/test" | ["X-fs-erpdss-token": "xxx"]      || 401    | _

        "正常"         | "middleware/sync/adapt/test" | ["X-fs-erpdss-token": getToken()] || 200    | "success"
    }

    def getToken() {
        Properties properties = new Properties()

        InputStream inputStream
        try {
            inputStream = TokenFilter.class.getClassLoader().getResourceAsStream("application.properties")
            properties.load(inputStream)
        } catch (IOException e) {
            throw new RuntimeException(e)
        } finally {
            if (inputStream != null) {
                try {
                    inputStream.close()
                } catch (IOException e) {
                    throw new RuntimeException(e)
                }
            }
        }

        return properties.getProperty("spring.security.user.token")
    }
}
